@@ -206,20 +206,28 @@ serve_dir = function(dir = '.') function(req) {
     type = guess_type(path)
     range = req$HTTP_RANGE
 
-    # Chrome sends the range reuest 'bytes=0-' and I'm not sure what to do:
-    # http://stackoverflow.com/a/18745164/559676
-    if (is.null(range) || identical(range, 'bytes=0-')) read_raw(path) else {
+    if (is.null(range)) {
+      read_raw(path)
+    } else {
       range = strsplit(range, split = "(=|-)")[[1]]
       b2 = as.numeric(range[2])
+      if (length(range) == 2 && range[1] == "bytes") {
+        # open-ended range request
+        # e.g. Chrome sends the range reuest 'bytes=0-'
+        # http://stackoverflow.com/a/18745164/559676
+        range[3] = file_size(path) - 1
+      }
       b3 = as.numeric(range[3])
-
-      if (length(range) < 3 || (range[1] != "bytes") || (b2 >= b3) || (b3 == 0))
+      if (length(range) < 3 || (range[1] != "bytes") || (b2 >= b3))
         return(list(
           status = 416L, headers = list('Content-Type' = 'text/plain'),
           body = 'Requested range not satisfiable\r\n'
         ))
 
       status = 206L  # partial content
+      # type may also need to be changed
+      # e.g. to "multipart/byteranges" if multipart range support is added at a later date
+      # or possibly to "application/octet-stream" for binary files
 
       con = file(path, open = "rb", raw = TRUE)
       on.exit(close(con))
@@ -231,7 +239,8 @@ serve_dir = function(dir = '.') function(req) {
   list(
     status = status, body = body,
     headers = c(list('Content-Type' = type), if (status == 206L) list(
-      'Content-Range' = paste(sub('=', ' ', req$HTTP_RANGE), file_size(path), sep = '/')
-    ))
+      'Content-Range' = paste0("bytes ", range[2], "-", range[3], "/", file_size(path))
+      ),
+      'Accept-Ranges: bytes') # indicates that the server supports range requests
   )
 }
